@@ -1,18 +1,17 @@
-# INTERNAL MODULE: a parameter within a Type::Params::Signature.
-
 package Type::Params::Parameter;
 
-use 5.008001;
+use 5.006001;
 use strict;
 use warnings;
 
 BEGIN {
+	if ( $] < 5.008 ) { require Devel::TypeTiny::Perl56Compat }
 	if ( $] < 5.010 ) { require Devel::TypeTiny::Perl58Compat }
 }
 
 BEGIN {
 	$Type::Params::Parameter::AUTHORITY  = 'cpan:TOBYINK';
-	$Type::Params::Parameter::VERSION    = '1.999_013';
+	$Type::Params::Parameter::VERSION    = '1.016000';
 }
 
 $Type::Params::Parameter::VERSION =~ tr/_//d;
@@ -28,19 +27,13 @@ sub new {
 	my $class = shift;
 
 	my %self  = @_ == 1 ? %{$_[0]} : @_;
-	$self{alias} ||= [];
-	if ( defined $self{alias} and not ref $self{alias} ) {
-		$self{alias} = [ $self{alias} ];
-	}
 
 	bless \%self, $class;
 }
 
-sub name       { $_[0]{name} }        sub has_name       { exists $_[0]{name} }
-sub type       { $_[0]{type} }        sub has_type       { exists $_[0]{type} }
-sub default    { $_[0]{default} }     sub has_default    { exists $_[0]{default} }
-sub alias      { $_[0]{alias} }       sub has_alias      { @{ $_[0]{alias} } }
-sub strictness { $_[0]{strictness} }  sub has_strictness { exists $_[0]{strictness} }
+sub name      { $_[0]{name} }       sub has_name      { exists $_[0]{name} }
+sub type      { $_[0]{type} }       sub has_type      { exists $_[0]{type} }
+sub default   { $_[0]{default} }    sub has_default   { exists $_[0]{default} }
 
 sub should_clone { $_[0]{clone} }
 
@@ -78,16 +71,9 @@ sub might_supply_new_value {
 }
 
 sub _code_for_default {
-	my ( $self, $signature, $coderef ) = @_;
+	my $self = shift;
 	my $default = $self->default;
 
-	if ( is_CodeRef $default ) {
-		my $default_varname = $coderef->add_variable(
-			'$default_for_' . $self->{vartail},
-			\$default,
-		);
-		return sprintf( '%s->( %s )', $default_varname, $signature->method_invocant );
-	}
 	if ( is_Undef $default ) {
 		return 'undef';
 	}
@@ -132,14 +118,6 @@ sub _make_code {
 		&& $constraint->parent->{uniq} eq Optional->{uniq}
 		&& $constraint->type_parameter;
 
-	my $strictness;
-	if ( $self->has_strictness ) {
-		$strictness = \ $self->strictness;
-	}
-	elsif ( $signature->has_strictness ) {
-		$strictness = \ $signature->strictness;
-	}
-
 	my ( $vartail, $exists_check );
 	if ( $args{is_named} ) {
 		my $bit = $args{key};
@@ -155,7 +133,6 @@ sub _make_code {
 
 	my $block_needs_ending = 0;
 	my $needs_clone = $self->should_clone;
-	my $in_big_optional_block = 0;
 
 	if ( $needs_clone and not $signature->{loaded_Storable} ) {
 		$coderef->add_line( 'use Storable ();' );
@@ -169,46 +146,26 @@ sub _make_code {
 		$constraint->display_name,
 	) );
 
-	if ( $args{is_named} and $self->has_alias ) {
+	if ( $self->has_default and is_CodeRef $self->default ) {
+		my $default_varname = $coderef->add_variable(
+			'$default_for_' . $vartail,
+			\ $self->default,
+		);
 		$coderef->add_line( sprintf(
-			'for my $alias ( %s ) {',
-			join( q{, }, map B::perlstring($_), @{ $self->alias } ),
-		) );
-		$coderef->increase_indent;
-		$coderef->add_line( 'exists $in{$alias} or next;' );
-		$coderef->add_line( sprintf(
-			'if ( %s ) {',
+			'$dtmp = %s ? %s : &%s;',
 			$exists_check,
+			$self->_maybe_clone( $varname ),
+			$default_varname,
 		) );
-		$coderef->increase_indent;
-		$coderef->add_line( sprintf(
-			'%s;',
-			$signature->_make_general_fail(
-				coderef  => $coderef,
-				message  => q{sprintf( 'Superfluous alias "%s" for argument "%s"', $alias, } . B::perlstring( $self->name || $args{input_slot} ) . q{ )},
-			),
-		) );
-		$coderef->decrease_indent;
-		$coderef->add_line( '}' );
-		$coderef->add_line( 'else {' );
-		$coderef->increase_indent;
-		$coderef->add_line( sprintf(
-			'%s = delete( $in{$alias} );',
-			$varname,
-		) );
-		$coderef->decrease_indent;
-		$coderef->add_line( '}' );
-		$coderef->decrease_indent;
-		$coderef->add_line( '}' );
+		$varname = '$dtmp';
+		$needs_clone = 0;
 	}
-
-	if ( $self->has_default ) {
-		$self->{vartail} = $vartail; # hack
+	elsif ( $self->has_default ) {
 		$coderef->add_line( sprintf(
 			'$dtmp = %s ? %s : %s;',
 			$exists_check,
 			$self->_maybe_clone( $varname ),
-			$self->_code_for_default( $signature, $coderef ),
+			$self->_code_for_default,
 		) );
 		$varname = '$dtmp';
 		$needs_clone = 0;
@@ -221,7 +178,6 @@ sub _make_code {
 			) );
 			$coderef->{indent} .= "\t";
 			++$block_needs_ending;
-			++$in_big_optional_block;
 		}
 		else {
 			$coderef->add_line( sprintf(
@@ -276,22 +232,11 @@ sub _make_code {
 	undef $Type::Tiny::ALL_TYPES{ $constraint->{uniq} };
 	$Type::Tiny::ALL_TYPES{ $constraint->{uniq} } = $constraint;
 
-	my $strictness_test = '';
-	if ( $strictness and $$strictness eq 1 ) {
-		$strictness_test = '';
-	}
-	elsif ( $strictness and $$strictness ) {
-		$strictness_test = sprintf "( not %s )\n\tor ", $$strictness;
-	}
-
-	if ( $strictness and not $$strictness ) {
-		$coderef->add_line( '1; # ... nothing to do' );
-	}
-	elsif ( $constraint->{uniq} == Any->{uniq} ) {
+	if ( $constraint->{uniq} == Any->{uniq} ) {
 		$coderef->add_line( '1; # ... nothing to do' );
 	}
 	elsif ( $constraint->can_be_inlined ) {
-		$coderef->add_line( $strictness_test . sprintf(
+		$coderef->add_line( sprintf(
 			"%s\n\tor %s;",
 			( $really_optional or $constraint )->inline_check( $varname ),
 			$signature->_make_constraint_fail(
@@ -308,7 +253,7 @@ sub _make_code {
 			'$check_for_' . $vartail,
 			\ ( ( $really_optional or $constraint )->compiled_check ),
 		);
-		$coderef->add_line( $strictness_test . sprintf(
+		$coderef->add_line( sprintf(
 			"&%s( %s )\n\tor %s;",
 			$compiled_check_varname,
 			$varname,
@@ -330,7 +275,7 @@ sub _make_code {
 		) );
 	}
 	elsif ( $args{output_slot} and $args{output_slot} ne $varname ) {
-		if ( !$in_big_optional_block and $varname =~ /\{/ ) {
+		if ( $varname =~ /\{/ ) {
 			$coderef->add_line( sprintf(
 				'%s = %s if exists( %s );',
 				$args{output_slot},
