@@ -1,49 +1,37 @@
-# INTERNAL MODULE: OO backend for Type::Params signatures.
-
 package Type::Params::Signature;
 
-use 5.008001;
+use 5.006001;
 use strict;
 use warnings;
 
 BEGIN {
+	if ( $] < 5.008 ) { require Devel::TypeTiny::Perl56Compat }
 	if ( $] < 5.010 ) { require Devel::TypeTiny::Perl58Compat }
 }
 
 BEGIN {
 	$Type::Params::Signature::AUTHORITY  = 'cpan:TOBYINK';
-	$Type::Params::Signature::VERSION    = '1.999_013';
+	$Type::Params::Signature::VERSION    = '1.016000';
 }
 
 $Type::Params::Signature::VERSION =~ tr/_//d;
 
 use B ();
-use Eval::TypeTiny::CodeAccumulator;
-use Types::Standard qw( -is -types -assert );
 use Types::TypeTiny qw( -is -types to_TypeTiny );
+use Types::Standard qw( -is -types -assert );
+use Type::Utils qw( dwim_type );
+use Type::Params::Coderef;
 use Type::Params::Parameter;
 
 sub _croak {
-	require Error::TypeTiny;
-	return Error::TypeTiny::croak( pop );
-}
-
-sub _new_parameter {
-	shift;
-	'Type::Params::Parameter'->new( @_ );
-}
-
-sub _new_code_accumulator {
-	shift;
-	'Eval::TypeTiny::CodeAccumulator'->new( @_ );
+	require Carp;
+	Carp::croak( pop );
 }
 
 sub new {
 	my $class = shift;
 	my %self  = @_ == 1 ? %{$_[0]} : @_;
 	my $self = bless \%self, $class;
-	$self->{parameters}   ||= [];
-	$self->{class_prefix} ||= 'Type::Params::OO::Klass';
 	$self->BUILD;
 	return $self;
 }
@@ -54,27 +42,9 @@ sub new {
 	sub BUILD {
 		my $self = shift;
 
-		if ( $self->{named_to_list} and not ref $self->{named_to_list} ) {
-			$self->{named_to_list} = [ map $_->name, @{ $self->{parameters} } ];
-		}
+		$self->{class_prefix} ||= 'Type::Params::OO::Klass';
 
-		if ( delete $self->{rationalize_slurpies} ) {
-			$self->_rationalize_slurpies;
-		}
-
-		if ( $self->{method} ) {
-			my $type = $self->{method};
-			$type =
-				is_Int($type) ? Defined :
-				is_Str($type) ? do { require Type::Utils; Type::Utils::dwim_type( $type, $self->{package} ? ( for => $self->{package} ) : () ) } :
-				to_TypeTiny( $type );
-			unshift @{ $self->{head} ||= [] }, $self->_new_parameter(
-				name    => 'invocant',
-				type    => $type,
-			);
-		}
-
-		if ( defined $self->{bless} and $self->{bless} eq 1 and not $self->{named_to_list} ) {
+		if ( defined $self->{bless} and $self->{bless} eq 1 ) {
 			my $klass_key     = $self->_klass_key;
 			$self->{bless}    = ( $klass_cache{$klass_key} ||= sprintf( '%s%d', $self->{class_prefix}, ++$klass_id ) );
 			$self->{oo_trace} = 1 unless exists $self->{oo_trace};
@@ -89,107 +59,44 @@ sub new {
 
 sub _klass_key {
 	my $self = shift;
-
-	my @parameters = @{ $self->parameters };
-	if ( $self->has_slurpy ) {
-		push @parameters, $self->slurpy;
-	}
-
 	no warnings 'uninitialized';
 	join(
 		'|',
 		map sprintf( '%s*%s*%s', $_->name, $_->getter, $_->predicate ),
-		sort { $a->{name} cmp $b->{name} } @parameters
+		sort { $a->{name} cmp $b->{name} } (
+			@{ $self->parameters || [] },
+			( $self->has_slurpy ? $self->slurpy : () )
+		)
 	);
 }
 
-sub _rationalize_slurpies {
-	my $self = shift;
-
-	my $parameters = $self->parameters;
-
-	if ( $self->is_named ) {
-		my ( @slurpy, @rest );
-
-		for my $parameter ( @$parameters ) {
-			if ( $parameter->type->is_strictly_a_type_of( Slurpy ) ) {
-				push @slurpy, $parameter;
-			}
-			elsif ( $parameter->{slurpy} ) {
-				$parameter->{type} = Slurpy[ $parameter->type ];
-				push @slurpy, $parameter;
-			}
-			else {
-				push @rest, $parameter;
-			}
-		}
-
-		if ( @slurpy == 1 ) {
-			my $constraint = $slurpy[0]->type;
-			if ( $constraint->type_parameter && $constraint->type_parameter->{uniq} == Any->{uniq} or $constraint->my_slurp_into eq 'HASH' ) {
-				$self->{slurpy} = $slurpy[0];
-				@$parameters = @rest;
-			}
-			else {
-				$self->_croak( 'Signatures with named parameters can only have slurpy parameters which are a subtype of HashRef' );
-			}
-		}
-		elsif ( @slurpy ) {
-			$self->_croak( 'Found multiple slurpy parameters! There can be only one' );
-		}
-	}
-	elsif ( @$parameters ) {
-		if ( $parameters->[-1]->type->is_strictly_a_type_of( Slurpy ) ) {
-			$self->{slurpy} = pop @$parameters;
-		}
-		elsif ( $parameters->[-1]{slurpy} ) {
-			$self->{slurpy} = pop @$parameters;
-			$self->{slurpy}{type} = Slurpy[ $self->{slurpy}{type} ];
-		}
-
-		for my $parameter ( @$parameters ) {
-			if ( $parameter->type->is_strictly_a_type_of( Slurpy ) or $parameter->{slurpy} ) {
-				$self->_croak( 'Parameter following slurpy parameter' );
-			}
-		}
-	}
-
-	if ( $self->{slurpy} and $self->{slurpy}->has_default ) {
-		require Carp;
-		our @CARP_NOT = ( __PACKAGE__, 'Type::Params' );
-		Carp::carp( "Warning: the default for the slurpy parameter will be ignored, continuing anyway" );
-		delete $self->{slurpy}{default};
-	}
-}
-
 sub _parameters_from_list {
 	my ( $class, $style, $list, %opts ) = @_;
 	my @return;
 	my $is_named = ( $style eq 'named' );
 
 	while ( @$list ) {
-		my ( $type, %param_opts );
+		if ( $is_named and is_Str( $list->[0] ) and is_HashRef( $list->[1] ) and $list->[1]{slurpy} ) {
+			last;
+		}
+		elsif ( !$is_named and is_HashRef( $list->[0] ) and $list->[0]{slurpy} ) {
+			last;
+		}
+
+		my %param_opts;
 		if ( $is_named ) {
 			$param_opts{name} = assert_Str( shift( @$list ) );
 		}
-		if ( is_HashRef $list->[0] and exists $list->[0]{slurpy} and not is_Bool $list->[0]{slurpy} ) {
-			my %new_opts = %{ shift( @$list ) };
-			$type = delete $new_opts{slurpy};
-			%param_opts = ( %param_opts, %new_opts, slurpy => 1 );
-		}
-		else {
-			$type = shift( @$list );
-		}
-		if ( is_HashRef( $list->[0] ) ) {
-			unless ( exists $list->[0]{slurpy} and not is_Bool $list->[0]{slurpy} ) {
-				%param_opts = ( %param_opts, %{ +shift( @$list ) } );
-			}
+		my $type = shift( @$list );
+		if ( is_HashRef( $list->[0] ) and not $list->[0]{slurpy} ) {
+			%param_opts = ( %param_opts, %{ +shift( @$list ) } );
 		}
 		$param_opts{type} =
-			is_Int($type) ? ( $type ? Any : do { $param_opts{optional} = !!1; Any; } ) :
-			is_Str($type) ? do { require Type::Utils; Type::Utils::dwim_type( $type, $opts{package} ? ( for => $opts{package} ) : () ) } :
+			is_Int($type)  ? ( $type ? Any : do { $param_opts{optional} = !!1; Any; } ) :
+			is_Str($type)  ? dwim_type( $type, $opts{package} ? ( for => $opts{package} ) : () ) :
 			to_TypeTiny( $type );
-		my $parameter = $class->_new_parameter( %param_opts );
+
+		my $parameter = 'Type::Params::Parameter'->new( %param_opts );
 		push @return, $parameter;
 	}
 
@@ -202,7 +109,7 @@ sub new_from_compile {
 	my $is_named = ( $style eq 'named' );
 
 	my %opts  = ();
-	while ( is_HashRef $_[0] and not exists $_[0]{slurpy} ) {
+	while ( is_HashRef( $_[0] )  and not $_[0]{slurpy} ) {
 		%opts = ( %opts, %{ +shift } );
 	}
 
@@ -218,54 +125,39 @@ sub new_from_compile {
 	$opts{is_named}   = $is_named;
 	$opts{parameters} = $class->_parameters_from_list( $style => $list, %opts );
 
-	my $self = $class->new( %opts, rationalize_slurpies => 1 );
-	return $self;
-}
+	if ( @$list ) {
+		my $name;
+		if ( $is_named ) {
+			$name = assert_Str( shift @$list );
+		}
+		assert_HashRef( $list->[0] );
+		$list->[0]{slurpy} or die;
 
-sub new_from_v2api {
-	my ( $class, $opts ) = @_;
+		my %slurpy = %{ shift @$list };
+		$slurpy{type} = $slurpy{slurpy};
+		$slurpy{name} = $name if defined $name;
+		if ( is_HashRef $list->[0] ) {
+			%slurpy = ( %slurpy, %{ shift @$list } );
+		}
+		$opts{slurpy} = 'Type::Params::Parameter'->new( %slurpy );
 
-	my $positional = delete( $opts->{positional} ) || delete( $opts->{pos} );
-	my $named      = delete( $opts->{named} );
-	my $multiple   = delete( $opts->{multiple} ) || delete( $opts->{multi} );
-
-	$class->_croak( "Signature must be positional, named, or multiple" )
-		unless $positional || $named || $multiple;
-
-	if ( $multiple ) {
-		$multiple = [] unless is_ArrayRef $multiple;
-		unshift @$multiple, { positional => $positional } if $positional;
-		unshift @$multiple, { named      => $named      } if $named;
-		require Type::Params::Alternatives;
-		return 'Type::Params::Alternatives'->new(
-			base_options => $opts,
-			alternatives => $multiple,
-			sig_class    => $class,
-		);
+		if ( @$list ) {
+			$class->_croak( 'Parameter following slurpy parameter' );
+		}
 	}
 
-	my ( $sig_kind, $args ) = ( pos => $positional );
-	if ( $named ) {
-		$opts->{bless} = 1 unless exists $opts->{bless};
-		( $sig_kind, $args ) = ( named => $named );
-		$class->_croak( "Signature cannot have both positional and named arguments" )
-			if $positional;
-	}
-
-	return $class->new_from_compile( $sig_kind, $opts, @$args );
+	return $class->new( %opts );
 }
 
 sub package       { $_[0]{package} }
 sub subname       { $_[0]{subname} }
 sub description   { $_[0]{description} }     sub has_description   { exists $_[0]{description} }
-sub method        { $_[0]{method} }
 sub head          { $_[0]{head} }            sub has_head          { exists $_[0]{head} }
 sub tail          { $_[0]{tail} }            sub has_tail          { exists $_[0]{tail} }
 sub parameters    { $_[0]{parameters} }      sub has_parameters    { exists $_[0]{parameters} }
 sub slurpy        { $_[0]{slurpy} }          sub has_slurpy        { exists $_[0]{slurpy} }
 sub on_die        { $_[0]{on_die} }          sub has_on_die        { exists $_[0]{on_die} }
-sub strictness    { $_[0]{strictness} }      sub has_strictness    { exists $_[0]{strictness} }
-sub goto_next     { $_[0]{goto_next} }
+
 sub is_named      { $_[0]{is_named} }
 sub bless         { $_[0]{bless} }
 sub class         { $_[0]{class} }
@@ -273,8 +165,6 @@ sub constructor   { $_[0]{constructor} }
 sub named_to_list { $_[0]{named_to_list} }
 sub oo_trace      { $_[0]{oo_trace} }
 
-sub method_invocant { $_[0]{method_invocant} = defined( $_[0]{method_invocant} ) ? $_[0]{method_invocant} : 'undef' }
-
 sub can_shortcut {
 	return $_[0]{can_shortcut}
 		if exists $_[0]{can_shortcut};
@@ -290,9 +180,9 @@ sub coderef {
 
 sub _build_coderef {
 	my $self = shift;
-	my $coderef = $self->_new_code_accumulator(
+	my $coderef = 'Type::Params::Coderef'->new(
 		description => $self->description
-			|| sprintf( q{parameter validation for '%s::%s'}, $self->package || '', $self->subname || '__ANON__' )
+			|| sprintf( 'parameter validation for "%s::%s"', $self->package, $self->subname )
 	);
 
 	$self->_coderef_start( $coderef );
@@ -316,23 +206,6 @@ sub _coderef_start {
 	$coderef->add_line( 'sub {' );
 	$coderef->{indent} .= "\t";
 
-	if ( my $next = $self->goto_next ) {
-		if ( is_CodeLike $next ) {
-			$coderef->add_variable( '$__NEXT__', \$next );
-		}
-		else {
-			$coderef->add_line( 'my $__NEXT__ = shift;' );
-			$coderef->add_gap;
-		}
-	}
-
-	if ( $self->method ) {
-		# Passed to parameter defaults
-		$self->{method_invocant} = '$__INVOCANT__';
-		$coderef->add_line( sprintf 'my %s = $_[0];', $self->method_invocant );
-		$coderef->add_gap;
-	}
-
 	$self->_coderef_start_extra( $coderef );
 
 	my $extravars = '';
@@ -371,17 +244,6 @@ sub _coderef_start_extra {}
 sub _coderef_check_count {
 	my ( $self, $coderef ) = ( shift, @_ );
 
-	my $strictness_test = '';
-	if ( defined $self->strictness and $self->strictness eq 1 ) {
-		$strictness_test = '';
-	}
-	elsif ( $self->strictness ) {
-		$strictness_test = sprintf '( not %s ) or ', $self->strictness;
-	}
-	elsif ( $self->has_strictness ) {
-		return $self;
-	}
-
 	my $headtail = 0;
 	$headtail += @{ $self->head } if $self->has_head;
 	$headtail += @{ $self->tail } if $self->has_tail;
@@ -390,7 +252,7 @@ sub _coderef_check_count {
 	my $min_args = 0;
 	my $max_args = 0;
 	my $seen_optional = 0;
-	for my $parameter ( @{ $self->parameters } ) {
+	for my $parameter ( @{ $self->parameters || [] } ) {
 		if ( $parameter->optional ) {
 			++$seen_optional;
 			++$max_args;
@@ -432,7 +294,7 @@ sub _coderef_check_count {
 				if defined $max_args_if_hash;
 		}
 
-		$coderef->add_line( $strictness_test . sprintf(
+		$coderef->add_line( sprintf(
 			"\@_ == %d && %s\n\tor \@_ %% 2 == %d%s\n\tor %s;",
 			$args_if_hashref,
 			HashRef->inline_check( sprintf '$_[%d]', $hashref_index ),
@@ -452,7 +314,7 @@ sub _coderef_check_count {
 		$self->{max_args} = $max_args;
 
 		if ( defined $max_args and $min_args == $max_args ) {
-			$coderef->add_line( $strictness_test . sprintf(
+			$coderef->add_line( sprintf(
 				"\@_ == %d\n\tor %s;",
 				$min_args,
 				$self->_make_count_fail(
@@ -464,7 +326,7 @@ sub _coderef_check_count {
 			) );
 		}
 		elsif ( $min_args and defined $max_args ) {
-			$coderef->add_line( $strictness_test . sprintf(
+			$coderef->add_line( sprintf(
 				"\@_ >= %d && \@_ <= %d\n\tor %s;",
 				$min_args,
 				$max_args,
@@ -477,7 +339,7 @@ sub _coderef_check_count {
 			) );
 		}
 		else {
-			$coderef->add_line( $strictness_test . sprintf(
+			$coderef->add_line( sprintf(
 				"\@_ >= %d\n\tor %s;",
 				$min_args || 0,
 				$self->_make_count_fail(
@@ -565,7 +427,7 @@ sub _coderef_parameters {
 
 		$coderef->add_gap;
 
-		for my $parameter ( @{ $self->parameters } ) {
+		for my $parameter ( @{ $self->parameters || [] } ) {
 			my $qname = B::perlstring( $parameter->name );
 			$parameter->_make_code(
 				signature   => $self,
@@ -584,7 +446,7 @@ sub _coderef_parameters {
 		my $head_size    = $self->has_head ? @{ $self->head } : 0;
 
 		my $i = 0;
-		for my $parameter ( @{ $self->parameters } ) {
+		for my $parameter ( @{ $self->parameters || [] } ) {
 			$parameter->_make_code(
 				signature   => $self,
 				coderef     => $coderef,
@@ -607,25 +469,24 @@ sub _coderef_slurpy {
 
 	my $parameter  = $self->slurpy;
 	my $constraint = $parameter->type;
-	my $slurp_into = $constraint->my_slurp_into;
-	my $real_type  = $constraint->my_unslurpy;
 
 	if ( $self->is_named ) {
 		$coderef->add_line( 'my $SLURPY = \\%in;' );
 	}
-	elsif ( $real_type and $real_type->{uniq} == Any->{uniq} ) {
+	elsif ( $constraint->{uniq} == Any->{uniq} ) {
 
 		$coderef->add_line( sprintf(
-			'my $SLURPY = [ @_[ %d .. $#_ ] ];',
-			scalar( @{ $self->parameters } ),
+			'my $SLURPY = { @_[ %d .. $#_ ] };',
+			scalar( @{ $self->parameters || [] } ),
 		) );
 	}
-	elsif ( $slurp_into eq 'HASH' ) {
+	elsif ( $constraint->is_a_type_of( HashRef )
+		or $constraint->is_a_type_of( Map )
+		or $constraint->is_a_type_of( Dict ) ) {
 
-		my $index = scalar( @{ $self->parameters } );
+		my $index = scalar( @{ $self->parameters || [] } );
 		$coderef->add_line( sprintf(
-			'my $SLURPY = ( $#_ == %d and ( %s ) ) ? { %%{ $_[%d] } } : ( ( $#_ - %d ) %% 2 ) ? { @_[ %d .. $#_ ] } : %s;',
-			$index,
+			'my $SLURPY = ( %s ) ? { %%{ $_[%d] } } : ( ( $#_ - %d ) %% 2 ) ? { @_[ %d .. $#_ ] } : %s;',
 			HashRef->inline_check("\$_[$index]"),
 			$index,
 			$index,
@@ -634,18 +495,23 @@ sub _coderef_slurpy {
 				coderef   => $coderef,
 				message   => sprintf(
 					qq{sprintf( "Odd number of elements in %%s", %s )},
-					B::perlstring( ( $real_type or $constraint )->display_name ),
+					B::perlstring( "$constraint" ),
 				),
 			),
 		) );
 	}
-	else {
+	elsif ( $constraint->is_a_type_of( ArrayRef )
+		or $constraint->is_a_type_of( Tuple )
+		or $constraint->is_a_type_of( CycleTuple ) ) {
 	
 		$coderef->add_line( sprintf(
 			'my $SLURPY = [ @_[ %d .. $#_ ] ];',
-			scalar( @{ $self->parameters } ),
+			scalar( @{ $self->parameters || [] } ),
 		) );
 	}
+	else {
+		$self->_croak( "Slurpy parameter not of type HashRef or ArrayRef" );
+	}
 
 	$coderef->add_gap;
 
@@ -664,18 +530,13 @@ sub _coderef_slurpy {
 sub _coderef_extra_names {
 	my ( $self, $coderef ) = ( shift, @_ );
 
-	return $self if $self->has_strictness && ! $self->strictness;
-
 	$coderef->add_line( '# Unrecognized parameters' );
 	$coderef->add_line( sprintf(
-		'%s if %skeys %%in;',
+		'%s if keys %%in;',
 		$self->_make_general_fail(
 			coderef   => $coderef,
 			message   => 'sprintf( q{Unrecognized parameter%s: %s}, keys( %in ) > 1 ? q{s} : q{}, join( q{, }, sort keys %in ) )',
 		),
-		defined( $self->strictness ) && $self->strictness ne 1
-			? sprintf( '%s && ', $self->strictness )
-			: ''
 	) );
 	$coderef->add_gap;
 }
@@ -683,16 +544,15 @@ sub _coderef_extra_names {
 sub _coderef_end {
 	my ( $self, $coderef ) = ( shift, @_ );
 
-	if ( $self->bless and $self->oo_trace ) {
+	if ( $self->bless and $self->oo_trace) {
 		my $package = $self->package;
 		my $subname = $self->subname;
-		if ( defined $package and defined $subname ) {
-			$coderef->add_line( sprintf(
-				'$out{"~~caller"} = %s;',
-				B::perlstring( "$package\::$subname" ),
-			) );
-			$coderef->add_gap;
-		}
+
+		$coderef->add_line( sprintf(
+			'$out{"~~caller"} = %s;',
+			B::perlstring( "$package\::$subname" ),
+		) );
+		$coderef->add_gap;
 	}
 
 	$self->_coderef_end_extra( $coderef );
@@ -716,12 +576,18 @@ sub _make_return_list {
 	if ( not $self->is_named ) {
 		push @return_list, $self->can_shortcut ? '@_' : '@out';
 	}
-	elsif ( $self->named_to_list ) {
+	elsif ( is_ArrayRef( $self->named_to_list ) ) {
 		push @return_list, map(
 			sprintf( '$out{%s}', B::perlstring( $_ ) ),
 			@{ $self->named_to_list },
 		);
 	}
+	elsif ( $self->named_to_list ) {
+		push @return_list, map(
+			sprintf( '$out{%s}', B::perlstring( $_->name ) ),
+			@{ $self->parameters || [] },
+		);
+	}
 	elsif ( $self->class ) {
 		push @return_list, sprintf(
 			'%s->%s( \%%out )',
@@ -749,22 +615,13 @@ sub _make_return_list {
 sub _make_return_expression {
 	my ( $self, %args ) = @_;
 
-	my $list = join q{, }, $self->_make_return_list;
-
-	if ( $self->goto_next ) {
-		if ( $list eq '@_' ) {
-			return sprintf 'goto( $__NEXT__ )';
-		}
-		else {
-			return sprintf 'do { @_ = ( %s ); goto $__NEXT__ }',
-				$list;
-		}
-	}
-	elsif ( $args{is_early} or not exists $args{is_early} ) {
-		return sprintf 'return( %s )', $list;
+	if ( $args{is_early} or not exists $args{is_early} ) {
+		return sprintf 'return( %s )',
+			join( q{, }, $self->_make_return_list );
 	}
 	else {
-		return sprintf '( %s )', $list;
+		return sprintf '( %s )',
+			join( q{, }, $self->_make_return_list );
 	}
 }
 
@@ -830,12 +687,7 @@ sub _build_class_attributes {
 	my %predicates;
 	my %getters;
 
-	my @parameters = @{ $self->parameters };
-	if ( $self->has_slurpy ) {
-		push @parameters, $self->slurpy;
-	}
-
-	for my $parameter ( @parameters ) {
+	for my $parameter ( @{ $self->parameters || [] } ) {
 
 		my $name = $parameter->name;
 		if ( my $predicate = $parameter->predicate ) {
@@ -860,7 +712,7 @@ sub make_class {
 	my $self = shift;
 	
 	my $env = uc( $ENV{PERL_TYPE_PARAMS_XS} || 'XS' );
-	if ( $env eq 'PP' or $ENV{PERL_ONLY} ) {
+	if ( $env eq 'PP' ) {
 		$self->make_class_pp;
 	}
 
@@ -898,10 +750,7 @@ sub make_class_pp {
 sub make_class_pp_code {
 	my $self = shift;
 
-	return ''
-		unless $self->is_named && $self->bless && !$self->named_to_list;
-
-	my $coderef = $self->_new_code_accumulator;
+	my $coderef = 'Type::Params::Coderef'->new;
 	my $attr    = $self->class_attributes;
 
 	$coderef->add_line( '{' );
@@ -942,18 +791,14 @@ sub return_wanted {
 	if ( $self->{want_source} ) {
 		return $coderef->code;
 	}
-	elsif ( $self->{want_object} ) { # undocumented for now
-		return $self;
-	}
 	elsif ( $self->{want_details} ) {
 		return {
-			min_args         => $self->{min_args},
-			max_args         => $self->{max_args},
-			environment      => $coderef->{env},
-			source           => $coderef->code,
-			closure          => $coderef->compile,
-			named            => $self->is_named,
-			class_definition => $self->make_class_pp_code,
+			min_args    => $self->{min_args},
+			max_args    => $self->{max_args},
+			environment => $coderef->{env},
+			source      => $coderef->code,
+			closure     => $coderef->compile,
+			named       => $self->is_named,
 		};
 	}
 
